@@ -1,8 +1,11 @@
 "howmany" <-
-function(pvalues,alpha=0.05,cutoff=0.05/length(pvalues))
+function(pvalues,alpha=0.05,cutoff=0.05/length(pvalues),m=length(pvalues))
   {
+
+    if(m<length(pvalues)) stop("total number of tests must cannot be smaller than number of supplied p-values")
+
+    m0 <- length(pvalues)
     
-    m <- length(pvalues)
     ord <- order(pvalues)
     pvalues <- pvalues[ord]
 
@@ -10,6 +13,7 @@ function(pvalues,alpha=0.05,cutoff=0.05/length(pvalues))
     howmany$order <- ord
     howmany$pvalues <- pvalues
     howmany$alpha <- alpha
+    howmany$m <- m
   
     ##cutoff
     pvalues[pvalues<cutoff] <- cutoff
@@ -18,9 +22,9 @@ function(pvalues,alpha=0.05,cutoff=0.05/length(pvalues))
     boundingfunction <- get.boundingfunction.independent(m,alpha,pvalues)
 
     ##compute the lower bound for the number of correct rejections
-    lowerbound <- numeric(m)
+    lowerbound <- numeric(m0)
     cummax <- 0
-    for (p in 1:m){
+    for (p in 1:m0){
 
       cummax <- max(cummax,floor((p-floor(boundingfunction[p]))/max(0.2,(1-pvalues[p]))))
       lowerbound[p] <- cummax
